@@ -3,8 +3,7 @@
 
 
 class BLOBError(Exception):
-    """ Exception raised by BLOB Host
-    """
+    """Exception raised by BLOB Host"""
 
     def __init__(self, message):
         self.message = message
