@@ -4,8 +4,6 @@ from blob_utils.blob_host import BLOBHost
 
 
 class DSpaceBLOBHost(BLOBHost):
-    """"""
-
     def __init__(self, blob_host_uri, blob_host_user, blob_host_password):
         """Initializes DSpace blob host
 
@@ -17,16 +15,16 @@ class DSpaceBLOBHost(BLOBHost):
         BLOBHost.__init__(self, blob_host_uri, blob_host_user, blob_host_password)
 
     def get(self, handle):
-        BLOBHost.get(self)
+        BLOBHost.get(self, handle)
 
     def list(self):
         BLOBHost.list(self)
 
     def save(self, blob, filename=None):
-        BLOBHost.save(self)
+        BLOBHost.save(self, blob, filename)
 
     def delete(self, handle):
-        BLOBHost.delete(self)
+        BLOBHost.delete(self, handle)
 
     def query(self, query):
-        BLOBHost.query(self)
+        BLOBHost.query(self, query)
